Features
===========

* `Using debuggers <debuggers.rst>`_
* `Using 3rd party packages <packages.rst>`_
* `Docking user windows <dock.rst>`_
* `Special support for Turtle programs <turtle.rst>`_
* `Specifying program arguments <program_arguments.rst>`_
* `Simple mode and expert mode <modes.rst>`_
* `Shell <shell.rst>`_
* `Plotter <plotter.rst>`_
* `Assistant <assistant.rst>`_
* `Birdseye <birdseye.rst>`_
* `Web development with Flask <flask.rst>`_

General topics
==============
* `Dealing with errors <errors.rst>`_
* `General advice on debugging <debugging.rst>`_

Online
======
There is more information available on turcar wiki: https://github.com/turcar/turcar/wiki.

